@@ -1,5 +1,5 @@
 # -*- coding:utf-8 -*-
-def print_lol(the_list, level):
+def print_lol(the_list, level = 0):
 #读取两个参数，"the_list"读取列表，"level"读取一个为0的数来进行嵌套。
     for a in the_list:
         if isinstance(a, list):
